==> coconut_develop-1.2.2.post0.dev4-py2.py3-none-any.whl: coconut/command/watch.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#-----------------------------------------------------------------------------------------------------------------------
# INFO:
#-----------------------------------------------------------------------------------------------------------------------

"""
Authors: Evan Hubinger, Fred Buchanan
License: Apache 2.0
Description: Handles interfacing with watchdog to make --watch work.
"""

#-----------------------------------------------------------------------------------------------------------------------
# IMPORTS:
#-----------------------------------------------------------------------------------------------------------------------

from __future__ import print_function, absolute_import, unicode_literals, division

from coconut.root import *  # NOQA

from coconut.exceptions import CoconutException

try:
    from watchdog.events import FileSystemEventHandler
    from watchdog.observers import Observer  # NOQA
except ImportError:
    raise CoconutException("--watch flag requires watchdog library",
                           extra="run 'pip install coconut[watch]' to fix")

#-----------------------------------------------------------------------------------------------------------------------
# CLASSES:
#-----------------------------------------------------------------------------------------------------------------------


class RecompilationWatcher(FileSystemEventHandler):

    def __init__(self, recompile):
        self.recompile = recompile

    def on_modified(self, event):
        self.recompile(event.src_path)

==> coconut_develop-1.2.3.post0.dev25-py2.py3-none-any.whl: coconut/command/watch.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#-----------------------------------------------------------------------------------------------------------------------
# INFO:
#-----------------------------------------------------------------------------------------------------------------------

"""
Authors: Evan Hubinger, Fred Buchanan
License: Apache 2.0
Description: Handles interfacing with watchdog to make --watch work.
"""

#-----------------------------------------------------------------------------------------------------------------------
# IMPORTS:
#-----------------------------------------------------------------------------------------------------------------------

from __future__ import print_function, absolute_import, unicode_literals, division

from coconut.root import *  # NOQA

from coconut.exceptions import CoconutException

try:
    from watchdog.events import FileSystemEventHandler
    from watchdog.observers import Observer  # NOQA
except ImportError:
    raise CoconutException("--watch flag requires watchdog library",
                           extra="run 'pip install coconut[watch]' to fix")

#-----------------------------------------------------------------------------------------------------------------------
# CLASSES:
#-----------------------------------------------------------------------------------------------------------------------


class RecompilationWatcher(FileSystemEventHandler):
    """Watcher that recompiles modified files."""

    def __init__(self, recompile):
        super(RecompilationWatcher, self).__init__()
        self.recompile = recompile
        self.keep_watching()

    def keep_watching(self):
        """Allows recompiling previously-compiled files."""
        self.saw = set()

    def on_modified(self, event):
        """Handle a file modified event."""
        path = event.src_path
        if path not in self.saw:
            self.saw.add(path)
            self.recompile(path)
